@@ -1,16 +1,9 @@
 import logging
-from slugify import slugify
 
 
 log = logging.getLogger(__name__)
 
 
-def listify(item):
-    if not isinstance(item, list):
-        return [item]
-    return item
-
-
 def retrieve_morpheme_id(o, g, lex, morph_type):
     candidates = lex[
         (lex["Form_Bare"].apply(lambda x: o in x))
@@ -29,10 +22,3 @@ def retrieve_morpheme_id(o, g, lex, morph_type):
         print(candidates)
         return candidates.iloc[0]["ID"]
     return None
-
-
-def get_slug(meaning, meanings):
-    slug_count = 0
-    while slugify(meaning) + "-" + str(slug_count) in meanings:
-        slug_count += 1
-    return slugify(meaning) + "-" + str(slug_count)
